"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const hash = require("string-hash");
const adminSockets = require.main.require('./src/socket.io/admin');
const db = require.main.require('./src/database');
const emojisKey = 'emoji:customizations:emojis';
const adjunctsKey = 'emoji:customizations:adjuncts';
exports.getCustomizations = async () => {
    const [emojis, adjuncts] = await Promise.all([
        db.getSortedSetRangeWithScores(emojisKey, 0, -1),
        db.getSortedSetRangeWithScores(adjunctsKey, 0, -1),
    ]);
    const emojisParsed = emojis.map((emoji) => JSON.parse(emoji.value));
    const adjunctsParsed = adjuncts.map((adjunct) => JSON.parse(adjunct.value));
    return {
        emojis: emojisParsed,
        adjuncts: adjunctsParsed,
    };
};
const editThing = async (key, name, thing) => {
    const num = hash(name);
    await db.sortedSetsRemoveRangeByScore([key], num, num);
    const thingNum = hash(thing.name);
    await db.sortedSetAdd(key, thingNum, JSON.stringify(thing));
};
const deleteThing = async (key, name) => {
    const num = hash(name);
    await db.sortedSetsRemoveRangeByScore([key], num, num);
};
const emojiSockets = {
    getCustomizations: exports.getCustomizations,
    editEmoji: async (socket, [name, emoji]) => editThing(emojisKey, name, emoji),
    deleteEmoji: async (socket, name) => deleteThing(emojisKey, name),
    editAdjunct: async (socket, [name, adjunct]) => editThing(adjunctsKey, name, adjunct),
    deleteAdjunct: async (socket, name) => deleteThing(adjunctsKey, name),
};
adminSockets.plugins.emoji = emojiSockets;
//# sourceMappingURL=customizations.js.map